@@ -8,12 +8,9 @@ if [ "x$1" = "x--chdir" ] ; then
 	shift
 fi
 
-aclocal
-autoheader
-automake -a -c
-autoconf
+autoreconf -i
 
 curdir="$(pwd)"
 mkdir -p -- "$configindir"
 cd "$configindir" || exit 1
-"$curdir"/configure --enable-maintainer-mode CFLAGS="-Wall -O2 -g -Wmissing-prototypes -Wstrict-prototypes -DSTUPIDCC=1" "$@"
+"$curdir"/configure --enable-maintainer-mode CFLAGS="-Wall -O2 -g -Wmissing-prototypes -Wstrict-prototypes -Wshadow" CPPFLAGS="-DSTUPIDCC=1" "$@"
